==> haskell-monad-journal-0.8.1-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-71CRxXXjW7wHtlUZKUpq6H
key:                  monad-journal-0.8.1-71CRxXXjW7wHtlUZKUpq6H
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  2084e8a3f1210d6eae224b0914d04cb7
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-71CRxXXjW7wHtlUZKUpq6H
depends:
    base-4.15.1.0 monad-control-1.0.3.1-HkiinuOeT8TKb2uZbjvoYb
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-Krt9Mny97mFI6zwkIY4Uue

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-32jL5iso1jX351XQw31PiR
key:                  monad-journal-0.8.1-32jL5iso1jX351XQw31PiR
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  92e7d23fc0b9802a5cb2acd3f59c4491
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-32jL5iso1jX351XQw31PiR
depends:
    base-4.15.1.0 monad-control-1.0.3.1-A10z0BeOAGys9XF8o3vyn mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-Iv23bfaB9S7861wmKQfWW8

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
